# Sgdrf

<!-- markdown-link-check-disable -->

[![Version status](https://img.shields.io/pypi/status/sgdrf)](https://opensource.org/license/mit/)

<!-- markdown-link-check-enable-->

[![License](https://img.shields.io/github/license/san-soucie/sgdrf)]()
[![Python version compatibility](https://img.shields.io/pypi/pyversions/sgdrf)](https://pypi.org/project/sgdrf)
[![Version on GitHub](https://img.shields.io/github/v/release/san-soucie/sgdrf?include_prereleases&label=GitHub)](https://github.com/san-soucie/sgdrf/releases)
[![Version on PyPi](https://img.shields.io/pypi/v/sgdrf)](https://pypi.org/project/sgdrf)
[![Documentation status](https://readthedocs.org/projects/sgdrf/badge)](https://sgdrf.readthedocs.io/en/latest)
[![Build (GitHub Actions)](https://img.shields.io/github/actions/workflow/status/san-soucie/sgdrf/push-main.yml?branch=main)](https://github.com/san-soucie/sgdrf/actions)
[![Test coverage (codecov)](https://codecov.io/github/san-soucie/sgdrf/coverage.svg)](https://codecov.io/gh/san-soucie/sgdrf)
[![Maintainability (Code Climate)](https://api.codeclimate.com/v1/badges/6b240648883c3a56c309/maintainability)](https://codeclimate.com/github/san-soucie/sgdrf/maintainability)
[![Created with Tyrannosaurus](https://img.shields.io/badge/Created_with-Tyrannosaurus-0000ff.svg)](https://github.com/dmyersturnbull/tyrannosaurus)

Python implementation of Streaming Gaussian Dirichlet Random Fields (San Soucie et al. 2023).

[See the docs 📚](https://sgdrf.readthedocs.io/) for more info.

Licensed under the terms of the [MIT License](https://spdx.org/licenses/MIT.html).
[New issues](https://github.com/san-soucie/sgdrf/issues) and pull requests are welcome.
Please refer to the [contributing guide](https://github.com/san-soucie/sgdrf/blob/main/CONTRIBUTING.md)
and [security policy](https://github.com/san-soucie/sgdrf/blob/main/SECURITY.md).
Generated with [Tyrannosaurus](https://github.com/dmyersturnbull/tyrannosaurus).
